@@ -34,7 +34,7 @@ from elyra._version import __version__
 from elyra.airflow.operator import BootscriptBuilder
 from elyra.metadata.schemaspaces import RuntimeImages
 from elyra.metadata.schemaspaces import Runtimes
-from elyra.pipeline.airflow.component_parser_airflow import AirflowComponentParser
+from elyra.pipeline.component_catalog import ComponentCache
 from elyra.pipeline.pipeline import GenericOperation
 from elyra.pipeline.processor import PipelineProcessor
 from elyra.pipeline.processor import PipelineProcessorResponse
@@ -76,7 +76,7 @@ be fully qualified (i.e., prefixed with their package names).
     class_import_map = {}
 
     def __init__(self, root_dir, **kwargs):
-        super().__init__(root_dir, component_parser=AirflowComponentParser(), **kwargs)
+        super().__init__(root_dir, **kwargs)
         if not self.class_import_map:  # Only need to load once
             for package in self.available_airflow_operators:
                 parts = package.rsplit(".", 1)
@@ -186,6 +186,12 @@ be fully qualified (i.e., prefixed with their package names).
         # Sort operations based on dependency graph (topological order)
         sorted_operations = PipelineProcessor._sort_operations(pipeline.operations)
 
+        # Determine whether access to cloud storage is required and check connectivity
+        for operation in sorted_operations:
+            if isinstance(operation, GenericOperation):
+                self._verify_cos_connectivity(runtime_configuration)
+                break
+
         # All previous operation outputs should be propagated throughout the pipeline.
         # In order to process this recursively, the current operation's inputs should be combined
         # from its parent's inputs (which, themselves are derived from the outputs of their parent)
@@ -249,7 +255,7 @@ be fully qualified (i.e., prefixed with their package names).
                              'image_pull_policy': image_pull_policy,
                              'cpu_request': operation.cpu,
                              'mem_request': operation.memory,
-                             'gpu_request': operation.gpu,
+                             'gpu_limit': operation.gpu,
                              'operator_source': operation.component_params['filename'],
                              'is_generic_operator': True
                              }
@@ -269,7 +275,7 @@ be fully qualified (i.e., prefixed with their package names).
 
             else:
                 # Retrieve component from cache
-                component = self._component_catalog.get_component(operation.classifier)
+                component = ComponentCache.instance().get_component(self._type, operation.classifier)
 
                 # Convert the user-entered value of certain properties according to their type
                 for component_property in component.properties:
@@ -349,7 +355,7 @@ be fully qualified (i.e., prefixed with their package names).
                              'class_name': component.name,
                              'parent_operation_ids': operation.parent_operation_ids,
                              'component_params': operation.component_params_as_dict,
-                             'operator_source': component.source_identifier,
+                             'operator_source': component.component_source,
                              'is_generic_operator': False
                              }
 
