@@ -15,18 +15,15 @@
  */
 
 import { MetadataService, RequestHandler } from '@elyra/services';
-import {
-  pipelineIcon,
-  kubeflowIcon,
-  airflowIcon,
-  pyIcon,
-  rIcon,
-  IconUtil
-} from '@elyra/ui-components';
-import { LabIcon, notebookIcon } from '@jupyterlab/ui-components';
+import { pyIcon, rIcon } from '@elyra/ui-components';
+import { notebookIcon } from '@jupyterlab/ui-components';
 import produce from 'immer';
 import useSWR from 'swr';
 
+import { PipelineService } from './PipelineService';
+
+export const GENERIC_CATEGORY_ID = 'Elyra';
+
 interface IReturn<T> {
   data?: T | undefined;
   error?: any;
@@ -73,7 +70,7 @@ interface IRuntimeComponentsResponse {
   categories: IRuntimeComponent[];
 }
 
-interface IRuntimeComponent {
+export interface IRuntimeComponent {
   label: string;
   image: string;
   id: string;
@@ -82,6 +79,9 @@ interface IRuntimeComponent {
   node_types: {
     op: string;
     id: string;
+    label: string;
+    image: string;
+    runtime_type?: string;
     type: 'execution_node';
     inputs: { app_data: any }[];
     outputs: { app_data: any }[];
@@ -114,58 +114,32 @@ interface IComponentPropertiesResponse {
   }[];
 }
 
-// TODO: We should decouple components and properties to support lazy loading.
-// TODO: type this
-const componentFetcher = async (runtime: string): Promise<any> => {
-  const palette = await RequestHandler.makeGetRequest<
-    IRuntimeComponentsResponse
-  >(`elyra/pipeline/components/${runtime}`);
-
-  // Gather list of component IDs to fetch properties for.
-  const componentList: string[] = [];
-  for (const category of palette.categories) {
-    for (const node of category.node_types) {
-      componentList.push(node.id);
+/**
+ * Sort palette in place. Takes a list of categories each containing a list of
+ * components.
+ * - Categories: alphabetically by "label" (exception: "generic" always first)
+ * - Components: alphabetically by "op" (where is component label stored?)
+ */
+export const sortPalette = (palette: {
+  categories: IRuntimeComponent[];
+}): void => {
+  palette.categories.sort((a, b) => {
+    if (a.id === GENERIC_CATEGORY_ID) {
+      return -1;
     }
-  }
-
-  const propertiesPromises = componentList.map(async componentID => {
-    const res = await RequestHandler.makeGetRequest<
-      IComponentPropertiesResponse
-    >(`elyra/pipeline/components/${runtime}/${componentID}/properties`);
-    return {
-      id: componentID,
-      properties: res
-    };
+    if (b.id === GENERIC_CATEGORY_ID) {
+      return 1;
+    }
+    return a.label.localeCompare(b.label, undefined, { numeric: true });
   });
 
-  // load all of the properties in parallel instead of serially
-  const properties = await Promise.all(propertiesPromises);
-
-  // inject properties
-  for (const category of palette.categories) {
-    // TODO: The server will provide this in a later release
-    switch (category.id) {
-      case 'kfp':
-        category.image = IconUtil.encode(kubeflowIcon);
-        break;
-      case 'airflow':
-        category.image = IconUtil.encode(airflowIcon);
-        break;
-      default:
-        category.image = IconUtil.encode(
-          IconUtil.colorize(pipelineIcon, '#808080')
-        );
-        break;
-    }
-
-    for (const node of category.node_types) {
-      const prop = properties.find(p => p.id === node.id);
-      node.app_data.properties = prop?.properties;
-    }
+  for (const components of palette.categories) {
+    components.node_types.sort((a, b) =>
+      a.label.localeCompare(b.label, undefined, {
+        numeric: true
+      })
+    );
   }
-
-  return palette;
 };
 
 // TODO: This should be enabled through `extensions`
@@ -184,42 +158,83 @@ const NodeIcons: Map<string, string> = new Map([
   ]
 ]);
 
-export const getRuntimeIcon = (runtime?: string): LabIcon => {
-  const runtimeIcons = [kubeflowIcon, airflowIcon];
-  for (const runtimeIcon of runtimeIcons) {
-    if (`elyra:${runtime}` === runtimeIcon.name) {
-      return runtimeIcon;
+// TODO: We should decouple components and properties to support lazy loading.
+// TODO: type this
+export const componentFetcher = async (type: string): Promise<any> => {
+  const palettePromise = RequestHandler.makeGetRequest<
+    IRuntimeComponentsResponse
+  >(`elyra/pipeline/components/${type}`);
+
+  const typesPromise = PipelineService.getRuntimeTypes();
+
+  const [palette, types] = await Promise.all([palettePromise, typesPromise]);
+
+  // Gather list of component IDs to fetch properties for.
+  const componentList: string[] = [];
+  for (const category of palette.categories) {
+    for (const node of category.node_types) {
+      componentList.push(node.id);
     }
   }
-  return pipelineIcon;
+
+  const propertiesPromises = componentList.map(async componentID => {
+    const res = await RequestHandler.makeGetRequest<
+      IComponentPropertiesResponse
+    >(`elyra/pipeline/components/${type}/${componentID}/properties`);
+    return {
+      id: componentID,
+      properties: res
+    };
+  });
+
+  // load all of the properties in parallel instead of serially
+  const properties = await Promise.all(propertiesPromises);
+
+  // inject properties
+  for (const category of palette.categories) {
+    // Use the runtime_type from the first node of the category to determine category
+    // icon.
+    // TODO: Ideally, this would be included in the category.
+    const category_runtime_type =
+      category.node_types?.[0]?.runtime_type ?? 'LOCAL';
+
+    const type = types.find((t: any) => t.id === category_runtime_type);
+    const defaultIcon = `/${type?.icon}`;
+
+    category.image = defaultIcon;
+
+    for (const node of category.node_types) {
+      // update icon
+      let nodeIcon = NodeIcons.get(node.op);
+      if (nodeIcon === undefined || nodeIcon === '') {
+        nodeIcon = defaultIcon;
+      }
+
+      // Not sure which is needed...
+      node.image = nodeIcon;
+      node.app_data.image = nodeIcon;
+      node.app_data.ui_data.image = nodeIcon;
+
+      const prop = properties.find(p => p.id === node.id);
+      node.app_data.properties = prop?.properties;
+    }
+  }
+
+  sortPalette(palette);
+
+  return palette;
 };
 
-export const usePalette = (pipelineRuntime = 'local'): IReturn<any> => {
+export const usePalette = (type = 'local'): IReturn<any> => {
   const { data: runtimeImages, error: runtimeError } = useRuntimeImages();
 
-  const { data: palette, error: paletteError } = useSWR(
-    pipelineRuntime,
-    componentFetcher
-  );
+  const { data: palette, error: paletteError } = useSWR(type, componentFetcher);
 
   let updatedPalette;
   if (palette !== undefined) {
     updatedPalette = produce(palette, (draft: any) => {
       for (const category of draft.categories) {
         for (const node of category.node_types) {
-          // update icon
-          let nodeIcon = NodeIcons.get(node.op);
-          if (nodeIcon === undefined || nodeIcon === '') {
-            nodeIcon =
-              'data:image/svg+xml;utf8,' +
-              encodeURIComponent(getRuntimeIcon(pipelineRuntime).svgstr);
-          }
-
-          // Not sure which is needed...
-          node.image = nodeIcon;
-          node.app_data.image = nodeIcon;
-          node.app_data.ui_data.image = nodeIcon;
-
           // update runtime images
           const runtimeImageIndex = node.app_data.properties.uihints.parameter_info.findIndex(
             (p: any) => p.parameter_ref === 'elyra_runtime_image'
